EasyExtend.langlets.p4d.p4dbase.P4DNamespace

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dbase :: Class P4DNamespace |
[hide private]
[frames] | no frames]

# Class P4DNamespace

    object --+
             |
            P4DNamespace

Instance Methods | [hide private]
__init__(self, prefix=None, uri=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
__str__(self) str(x) |
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
add_namespace(cls, prefix, uri) |
get(self, key) |

Class Variables | [hide private]
| _namespaces = ``{``'``bl``'``:` `'``http://fiber-space.de/blns``'``,` `'``bl-schema``'``...``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, prefix=None, uri=None) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)

Class Variable Details | [hide private]

  ### _namespaces Value:
      {'bl': 'http://fiber-space.de/blns',
       'bl-schema': 'http://fiber-space.de/bl-schemans',
       'http://fiber-space.de/bl-schemans': 'bl-schemans',
       'http://fiber-space.de/blns': 'bl',
       'http://fiber-space.de/p4dns': 'p4d',
       'http://www.w3.org/2000/xmlns': 'xmlns',
       'p4d': 'http://fiber-space.de/p4dns',
       'xmlns': 'http://www.w3.org/2000/xmlns'}